aboutsummaryrefslogtreecommitdiffstats
path: root/pop3.c
diff options
context:
space:
mode:
Diffstat (limited to 'pop3.c')
-rw-r--r--pop3.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/pop3.c b/pop3.c
index 0be6b211..5571d6d9 100644
--- a/pop3.c
+++ b/pop3.c
@@ -70,8 +70,8 @@ struct hostrec *queryctl;
int first,number,count;
- /* open/lock the folder if we're using a mailbox */
- if (queryctl->output == TO_FOLDER)
+ /* open stdout or the mailbox, locking it if it is a folder */
+ if (queryctl->output == TO_FOLDER || queryctl->output == TO_STDOUT)
if ((mboxfd = openuserfolder(queryctl)) < 0)
return(PS_IOERR);